@@ -4,6 +4,7 @@ from harpoon.errors import NoSuchKey, BadOption, NoSuchImage, BadCommand, BadIma
 from harpoon.formatter import MergedOptionStringFormatter
 from harpoon.helpers import a_temp_file, until
 from harpoon.processes import command_output
+from harpoon.layers import Layers
 
 from docker.errors import APIError as DockerAPIError
 from option_merge import MergedOptions
@@ -67,6 +68,11 @@ class Image(object):
 
         return first_command.split(" ", 1)[1]
 
+    def dependencies(self, images):
+        """Yield just the dependency images"""
+        for image, _ in self.dependency_images(images):
+            yield image
+
     def dependency_images(self, images, ignore_parent=False):
         """
         What images does this one require
@@ -445,8 +451,7 @@ class Image(object):
             try:
                 for line in self.docker_context.build(fileobj=context, custom_context=True, tag=self.image_name, stream=True, rm=True):
                     line_detail = None
-                    try:
-                        line_detail = json.loads(line)
+                    try: line_detail = json.loads(line)
                     except (ValueError, TypeError) as error:
                         log.warning("line from docker wasn't json", got=line, error=error)
 
@@ -846,6 +851,13 @@ class Image(object):
         else:
             raise BadOption("Don't understand dictionary value for spec", command=[name, value], image=self.name)
 
+    def display_line(self):
+        """A single line describing this image"""
+        msg = ["Image {0}".format(self.name)]
+        if self.heira_formatted("image_index", default=None):
+            msg.append("Pushes to {0}".format(self.image_name))
+        return ' : '.join(msg)
+
 class Imager(object):
     """Knows how to build and run docker images"""
     def __init__(self, configuration, docker_context, interactive=True, silent_build=False):
@@ -880,7 +892,7 @@ class Imager(object):
         except DockerAPIError as error:
             raise BadImage("Failed to start the container", error=error)
 
-    def make_image(self, image, chain=None, made=None):
+    def make_image(self, image, chain=None, made=None, ignore_deps=False):
         """Make us an image"""
         if chain is None:
             chain = []
@@ -898,8 +910,9 @@ class Imager(object):
         if image not in images:
             raise NoSuchImage(looking_for=image, available=images.keys())
 
-        for dependency, _ in images[image].dependency_images(images):
-            self.make_image(dependency, chain=chain + [image], made=made)
+        if not ignore_deps:
+            for dependency, _ in images[image].dependency_images(images):
+                self.make_image(dependency, chain=chain + [image], made=made)
 
         # Should have all our dependencies now
         instance = images[image]
@@ -907,3 +920,15 @@ class Imager(object):
         instance.build_image()
         made[image] = True
 
+    def layered(self, only_pushable=False):
+        """Yield layers of images"""
+        images = self.images
+        if only_pushable:
+            operate_on = dict((image, instance) for image, instance in images.items() if instance.heira_formatted("image_index", default=None))
+        else:
+            operate_on = images
+
+        layers = Layers(operate_on, all_images=images)
+        layers.add_all_to_layers()
+        return layers.layered
+
