@@ -114,8 +114,17 @@ class Harpoon(object):
         return {
               "ssh": Task(available_tasks["run_task"], kwargs={"command":"/bin/bash"}, description="Run bash in one of the containers")
             , "run": Task(available_tasks["run_task"], description="Run a command in one of the containers")
+
             , "make": Task(available_tasks["make"], description="Make one of the images")
-            , "push": Task(available_tasks["push"], description="Push an image")
+            , "make_all": Task(available_tasks["make_all"], description="Make all of the images")
+            , "make_pushable": Task(available_tasks["make_pushable"], description="Make only the pushable images and their dependencies")
+
+            , "push": Task(available_tasks["push"], description="Push one of the images")
+            , "push_all": Task(available_tasks["push_all"], description="Push all of the images")
+
+            , "show": Task(available_tasks["show"], description="Show the available images")
+            , "show_pushable": Task(available_tasks["show_pushable"], description="Show the layers for only the pushable images")
+
             , "list_tasks": Task(available_tasks["list_tasks"], description="List the available tasks")
             , "delete_untagged": Task(available_tasks["delete_untagged"], description="Delete untagged images")
             }
